@@ -9,7 +9,7 @@ from pygame.transform import flip
 from pygame.draw import line
 from pygame.version import ver
 import math as mh
-import Ipygame as ipg
+import lddya.Ipygame as ipg
 
 ################################################## 1 蚁群算法路径规划 ###########################################
 
@@ -1393,6 +1393,8 @@ class ShanGeTu():
             b_1 = self.final_opt_way[i+1]
             self.way_lenght += (((a_1[0]-b_1[0])**2)+((a_1[1]-b_1[1])**2))**0.5
         self.way_lenght = self.way_lenght/self.cell_size
+        
+        
 
 
 
